@@ -13,8 +13,8 @@ module Sessions
 class Meterpreter_x86_Linux < Msf::Sessions::Meterpreter
   def initialize(rstream, opts={})
     super
-    self.platform      = 'x86/linux'
-    self.binary_suffix = 'lso'
+    self.base_platform = 'linux'
+    self.base_arch = ARCH_X86
   end
 end
 
